/*******************************************************************************
#
#        L o g i c a l s:   H e a d e r
#
#*******************************************************************************

   DEPENDENCIES:
      qnxos.h
      Assumes existence of a global variable Logicals[]
      
   HISTORY:

      03/26/03 - rfm - added a bunch of PNP_SEM to catch up with what is
                       in /cell.def/logi_specs.def
                              
      12/13/02 - rfm - Added HSDA_FTP_RESULTS
         
      12/08/02 - rfm - changed CDS_MACH_STATE_INIT_SEM to HSDA_RESULTS_INIT_SEM
      
      11/14/02 - clf - added NGET_TCP

      08/14/02 - ljl - added ATA_COMMENT
      
      04/26/02 - ljl - added console freeze flags
      
      07/11/01 - ljl - changed PLIST_SEM to CYBER_SEM
         
      05/31/01 - rfm - Changed 'VALID_TO_LOG_LABEL_ERRS' to 
                       'REDIRECT_LOGGING_ERRS'

      04/10/01 - rfm - Added emission pnp logicals
      
      03/19/01 - rfm - Added VALID_TO_LOG_LABEL_ERRS
      
      10/12/00 - ljl - added SPEC_FILE_RCS
      
      07/20/00 - rfm - Added DO_PWM_CONFIG_SEM for DO_PWM transfer
                       process.
                       
      01/25/00 - rfm - Added #define CT for cybertruck subsystems.

      01/25/00 - rfm - modified defines for subsystems.
      
      10/12/99 - dlg - added UNITS_UPDATE_SEM for adding units to the system

      08/27/99 - ljl - added ENGINE_INSTALL_VALID
      
      03/01/99 - ljl - added DT_START_ENABLE
      
      09/10/98 - ljl - added DYNO_FF_COMPUTE and THROTTLE_FF_COMPUTE
      
      07/03/98 - ljl - added PROPERTIES_SEM for properties memory 
                       initialization
      
      02/18/98 - bet - added SIG_MEM_SEM
   
      08/05/97 - ljl - added 1200 speed flag
      
      07/30/97 - ljl - added the LIMIT_FORMAT_FLAG and AUTO_CAL_FLAG
      
      01/27/97 - ljl - added FORCE_METER define
      
      10/24/96 - ljl - added ATA_LINK_STATUS
      
      08/02/96 - clf - Add FUELSYS_ONE_SHOT_SEM

      07/08/96 - dar - changed define 97 from PCC_STATE_INIT_SEM to
                       CDS_MACH_STATE_INIT_SEM   

      04/03/96 - ljl - added WFA_RUN_REQ and GP_TRACE
      
      02/08/96 - bet - added CO_CONFIG_SEM, CO_SPC_SEM

      05/26/95 - ljl - added a note about the maximum range for semaphores
                       (increased to 124)
                       
$Log: logicals.h,v $
Revision 1.42  2003-03-26 10:16:15-05  rick
*

Revision 1.41  2002-12-16 12:09:41-05  rick
*

Revision 1.40  2002-12-09 14:38:04-05  rick
*

Revision 1.39  2002-12-09 14:22:55-05  curt
*

Revision 1.38  2002-09-10 07:51:43-05  len
Revision 1.37  2002-08-14 08:32:16-05  len
Revision 1.36  2002-08-08 09:12:35-05  len
Revision 1.35  2002-04-26 14:09:11-05  len
Revision 1.34  2002-04-26 10:56:52-05  len
Revision 1.33  2001-07-11 13:41:42-05  len
Revision 1.32  2001-05-31 15:30:15-05  rick
Revision 1.31  2001-04-20 10:34:55-05  rick
Revision 1.30  2001-03-20 16:24:34-05  rick
Revision 1.29  2000-10-12 08:53:01-05  len
Revision 1.28  2000-07-20 13:33:10-05  rick
Revision 1.27  2000-01-25 08:16:09-05  rick
Revision 1.26  2000-01-25 08:08:43-05  rick
Revision 1.25  2000-01-20 17:09:49-05  len
Revision 1.24  1999-10-12 13:09:51-05  duane
Revision 1.23  1999-08-27 14:14:50-05  len
Revision 1.22  1999-05-24 08:38:41-05  len
Revision 1.21  1999-03-01 09:14:07-05  len
Revision 1.20  1998-09-10 15:17:34-05  len
Revision 1.19  1998-09-10 10:08:35-05  len
Revision 1.18  1998-07-03 13:37:34-05  len
Revision 1.17  1998/02/18 13:59:20  bruce
Revision 1.16  1997/08/18 14:33:34  len
Revision 1.15  1997/08/05 11:29:50  len
Revision 1.14  1997/07/30 15:42:24  len
Revision 1.13  1997/07/30 15:31:35  len
Revision 1.12  1997/01/28 18:52:22  len
Revision 1.11  1996/12/30 14:48:33  len
Revision 1.10  1996/10/25 01:17:46  len
Revision 1.9  1996/08/02 18:50:48  curt
Revision 1.8  1996/07/19 20:15:24  len
Revision 1.7  1996/07/08 20:09:37  dave
Revision 1.6  1996/04/03  17:41:14  len
Revision 1.5  1996/02/08  19:03:35  bruce
Revision 1.4  1995/05/26  17:35:45  len
Revision 1.3  1995/01/12  11:37:07  len

      Revision 1.54 Mon Nov 28 10:14:35 1994 len
  
  
   the following group of defines are used to define the organization of the
   LOGI_MEM shared memory area.  It is an array of LOGICAL_VARIABLEs of size
   MAX_LOGICAL_VALUES
*/


/* the following define dedicated usage of logical variables in the LOGICALS
   shared memory area
*/

# define ENGINE_RUNNING           0    /* true if engine rpm > 10          */
#define FORCE_METER               1   /* true to force hour meter to run */
# define DYNO_FF_COMPUTE           2   /* true if dyno_ff task is providing
                                         the FF input */
# define THROTTLE_FF_COMPUTE       3   /* true if throttle_ff task is providing
                                         the FF input */
# define SAFETY_SHUTDOWN          4    /* true if safeties shut engine off */
# define GP_TRACE                 5    /* true for tracing */
# define CONTROLLERS_ACTIVE       6    /* true if engine controllers active*/
# define ENGINE_SPD_GT800         7    /* true if engine rpm > 800         */
# define ENGINE_SPD_GT400         8    /* true if engine rpm > 400         */
# define ENABLE_LOWER_LIMITS      9   
# define FUEL_READING_IP         10    /* fuel reading in progress */      
                                       /* fuel reading request for a single
                                       fuel reading */
# define FR_RQST_ONE             11
                                       /* fuel reading request for continuous
                                       fuel readings */
# define FR_RQST_CONTINUOUS      12
                                       /* flag for whether to use automatic wt
                                       selection algorithm for scales or to use
                                       the "requested_fuel_weight" in the fuel
                                       reading data structure */  
# define FR_WT_AUTO              13

                                       /* flag indicating that a test shutdown
                                       has been initiated */
# define ABORT_SHUTDOWN          14
                                       /* flag which indicates that the test
                                       program is to be terminated after the
                                       current test cycle is complete. */
# define LAST_CYCLE              15



# define SHUTDOWN_INCIDENT       16    /* a slow abort or emergency shutdown
                                       has been initiated */
                                       
                                       /* flag which indicates that Fuel
                                       Reading data is written to disk for
                                       transfer to the network EPDA server.
                                       TRUE = write file to disk
                                       FALSE = do not write file to disk */
# define FR_DISK_WRITE           18
                                       /* flag which indicates that test hours
                                       are to be accumulated,  test hours will
                                       accumulate if 
                                       ENGINE_RUNNING  .or. TEST_HOURS_ACCUM
                                       .and. TEST_HOURS_ENABLE 
                                       is  TRUE */
#define TEST_HOURS_ACCUM         19

                                       /* flag which can be used to disable the
                                       test hours clock whether or not the 
                                       engine is running */
#define TEST_HOURS_ENABLE        20
                                       /* flag which indicates that Fuel
                                       Reading data is written to disk for
                                       logging.
                                       TRUE = write logginf file to disk
                                       FALSE = do not write logging file to 
                                               disk */
# define FR_LOG_WRITE            21

                                       /* flag which indicates that the 
                                       threshold value for the hour meter
                                       variable has been exceeded */
# define METER_RUNNING           22
   
                                       /* flag which means the AVL smokemeter
                                       is in use - this can be used to allow
                                       a meter to be shared between 2 cells */
# define AVL_RESERVED            23    

# define WFA_RUN_REQUEST         24    /* used to turn the "wfa_task" on
                                       only when the engine is running */

#define ATA_LINK_STATUS          25    /* same as Sys_attr->ATA_link_status */

                                       /* flag which indicates whether the
                                       limit logicals show units or not
                                         0 - show units
                                         1 - don't show units */
# define LIMIT_FORMAT_FLAG       26    


# define AUTO_CAL_FLAG           27    /* flag for auto calibration of
                                       speed channel 
                                         0 - auto cal enabled
                                         1 - auto cal disabled
                                       */

# define ENGINE_SPD_GT1000        28    /* true if engine rpm > 1000rpm   */
# define ENGINE_SPD_GT1200        29    /* true if engine rpm > 1200rpm   */
# define ENGINE_SPD_GT1400        30    /* true if engine rpm > 1400rpm   */
# define ENGINE_SPD_GT1600        31    /* true if engine rpm > 1600rpm   */
# define ENGINE_SPD_GT1800        32    /* true if engine rpm > 1800rpm   */
# define ENGINE_SPD_GT2000        33    /* true if engine rpm > 2000rpm   */
# define ENGINE_SPD_GT2200        34    /* true if engine rpm > 2200rpm   */
# define ENGINE_SPD_GT2400        35    /* true if engine rpm > 2400rpm   */
# define ENGINE_SPD_GT2600        36    /* true if engine rpm > 2600rpm   */

#define  DT_START_ENABLE          37    /* enable set by the downtime monitor*/
#define  EPA_FA_OKAY              38    /* is EPA_fa_okay in range */
#define  ENGINE_INSTALL_VALID     39    /* true when an engine is installed
                                           in the cell */

#define  SPEC_FILE_RCS            40    /* flag to disable version control
                                           of spec files - 0 is enable
                                                           1 is disable
                                        */


                                        /* flags for freezing display
                                        consoles */

#define  FRZ_CON1                 41
#define  FRZ_CON2                 42
#define  FRZ_CON3                 43
#define  FRZ_CON4                 44
#define  FRZ_CON5                 45
#define  FRZ_CON6                 46
#define ATA_COMMENT               47    /* print messages from ata_coll or
                                       ramp_coll if true */
				   
#define NGET_TCP                  48    /* if set, use nget tcp interface
                                          otherwise use local nget app */                                       
                                       
#define HSDA_FTP_RESULTS          49    /* set true when HSDA results were
                                           successfully ftp'd */

                                           
/* the following defines are for the set of logical variables which are
   reserved for initialization semaphores */
   
#define SYS_ATTR_SEM             50 
#define LOGI_SEM                 51
#define TEST_LIMIT_CONFIG_SEM    52
#define AI_ATTR_SEM              53
#define AO_ATTR_SEM              54
#define DI_ATTR_SEM              55
#define DO_ATTR_SEM              56
#define AI_SPC_SEM               57
#define AO_SPC_SEM               58
#define LIMIT_CONFIG_SEM         59
#define LIMIT_SPC_SEM            60
#define CTL_SPC_SEM             61
#define ENG_SPC_SEM             62
#define AI_TRAN_SEM             63
#define DSPLY_DATA_SEM          64
#define MS_SEM                  65
#define DI_LOGI_CONFIG_SEM      66
#define DO_LOGI_CONFIG_SEM      67
#define AO_CONFIG_SEM           68
#define EP_CONFIG_SEM           69
#define AI_CONFIG_SEM           70
#define CTL_CONFIG_SEM          71
#define HST_CONFIG_SEM          72
#define HST_SPC_SEM             73
#define LABELS_SEM              74
#define CYBER_SEM               75
#define DEVICE_ATTR_SEM         76
#define FICI_ATTR_SEM           77
#define FICI_SPC_SEM            78
#define FICI_CONFIG_SEM         79
#define GEN_USE_SEM             80
#define CAL_TABLES_SEM          81
#define DI_LOGI_SPC_SEM         82
#define DI_INTG_SPC_SEM         83
#define DO_LOGI_SPC_SEM         84
#define DO_INTG_SPC_SEM         85
#define DI_INTG_CONFIG_SEM      86
#define DO_WORD_CONFIG_SEM      87
#define CT_ATTR_SEM             88
#define DA_SEM                  89
#define ASSET_INIT_SEM          90
#define RA_SEM                  91
#define HSDA_STARTED_SEM        92 
#define UNITS_INIT_SEM          93
#define TRANST_SEM              94
#define KEYWORD_INIT_SEM        95
#define CO_ATTR_SEM             96
#define HSDA_RESULTS_INIT_SEM   97  /* hsda_results is active and initialized */
#define SM_ATTR_SEM             98
#define CT_ACCESS_SEM           99
#define CO_CONFIG_SEM          100
#define CO_SPC_SEM             101
#define FUELSYS_ONE_SHOT_SEM   102
#define SNAP_SEM               103
#define SIG_MEM_SEM            104
#define PROPERTIES_SEM         105
#define UNITS_UPDATE_SEM       106
#define LOS_PNP_SEM            107
#define EM_FR_NO_CART_PNP_SEM  108
#define PIER_PNP_SEM           109
#define PNP_415_SEM            110
#define PNP_409_SEM            111
#define PNP_439_SEM            112
#define HSDA_PNP_SEM           113
#define SMOC_PNP_SEM           114
#define CT_PNP_SEM             115
#define PIER_2_PNP_SEM         116
#define DO_PWM_CONFIG_SEM      117
#define REDIRECT_LOGGING_ERRS  118
#define EM_FR_WITH_CART_PNP_SEM  119
#define EM_RT_CO2_PNP_SEM        120
#define EM_RT_FUEL_CMD_PNP_SEM   121
#define EM_RT_FUEL_CONT_PNP_SEM  122
#define CENSE_PNP_SEM            123
#define GOAL_PNP_SEM             124
#define PMS_PNP_SEM              125 
#define HART_PNP_SEM             126 
#define EM_CART31_PNP_SEM        127 
#define EM_CART32_PNP_SEM        128 
#define EM_CART90_PNP_SEM        129 
#define EM_CART91_PNP_SEM        130 
#define EM_CART92_PNP_SEM        131 
#define EM_CART93_PNP_SEM        132 
#define EM_CART94_PNP_SEM        133 
#define EM_CART95_PNP_SEM        134 
#define EM_CART96_PNP_SEM        135 
#define EM_CART97_PNP_SEM        136 
#define EM_CART98_PNP_SEM        137 
#define EM_CART99_PNP_SEM        138 
#define EM_CART100_PNP_SEM       139 
#define EM_CART101_PNP_SEM       140 
#define EM_CART102_PNP_SEM       141 
#define EM_CART103_PNP_SEM       142 
#define EM_CART104_PNP_SEM       143 
#define EM_CART105_PNP_SEM       144 
#define AI_SPECS_PNP_SEM         145 

#define ES_PNP_SEM

/* NOTE: the range of indexes available for semaphores is 50 to
         MAX_LOGICAL_VALUES (200 - see asset.h for define )
*/

                                       /* definition of a set of general 
                                          purpose set of logical parameters

                                       */

/* define some macros to address various parameters in shared memory */
                         
                       

#define LOGI_VALUE( a )           Logicals[ a ].value
#define LOGI_STATUS( a )          Logicals[ a ].status
